@@ -1,7 +1,31 @@
 
+__all__ = [
+    'NONE',
+    'DEBUG',
+    'STRICT',
+    'MEMOIZE',
+    'OPTIMIZE',
+    'Error',
+    'GrammarWarning',
+    'GrammarError',
+    'ParseError',
+    'Grammar',
+    'Match',
+    'escape',
+    'unescape',
+    'Parser',
+    'compile',
+    'match',
+]
+
 from pe._meta import __version__  # noqa: F401
 from pe._constants import Flag
-from pe._errors import Error, GrammarError, ParseError
+from pe._errors import (
+    Error,
+    GrammarWarning,
+    GrammarError,
+    ParseError,
+)
 from pe._grammar import Grammar
 from pe._match import Match
 from pe._escape import escape, unescape
@@ -16,22 +40,3 @@ MEMOIZE = Flag.MEMOIZE
 INLINE = Flag.INLINE
 REGEX = Flag.REGEX
 OPTIMIZE = Flag.OPTIMIZE
-
-
-__all__ = [
-    'NONE',
-    'DEBUG',
-    'STRICT',
-    'MEMOIZE',
-    'OPTIMIZE',
-    'Error',
-    'GrammarError',
-    'ParseError',
-    'Grammar',
-    'Match',
-    'escape',
-    'unescape',
-    'Parser',
-    'compile',
-    'match',
-]
